@@ -516,9 +516,23 @@ void KateMainWindow::slotEditToolbars()
     dlg.exec();
 }
 
+void KateMainWindow::reloadXmlGui()
+{
+    for (KTextEditor::Document* doc : KateApp::self()->documentManager()->documentList()) {
+        doc->reloadXML();
+        for (KTextEditor::View* view : doc->views()) {
+            view->reloadXML();
+        }
+    }
+}
+
 void KateMainWindow::slotNewToolbarConfig()
 {
     applyMainWindowSettings(KConfigGroup(KSharedConfig::openConfig(), "MainWindow"));
+
+    // we neeed to relod all View's XML Gui from disk to ensure toolbar
+    // changes are applied to all views.
+    reloadXmlGui();
 }
 
 void KateMainWindow::slotFileQuit()
@@ -742,16 +756,8 @@ void KateMainWindow::editKeys()
     }
     dlg.configure();
 
-    QList<KTextEditor::Document *>  l = KateApp::self()->documentManager()->documentList();
-    for (int i = 0; i < l.count(); i++) {
-//     qCDebug(LOG_KATE)<<"reloading Keysettings for document "<<i;
-        l.at(i)->reloadXML();
-        QList<KTextEditor::View *> l1 = l.at(i)->views();
-        for (int i1 = 0; i1 < l1.count(); i1++) {
-            l1.at(i1)->reloadXML();
-//       qCDebug(LOG_KATE)<<"reloading Keysettings for view "<<i<<"/"<<i1;
-        }
-    }
+    // reloadXML gui clients, to ensure all clients are up-to-date
+    reloadXmlGui();
 }
 
 void KateMainWindow::openUrl(const QString &name)
@@ -1092,6 +1098,19 @@ QObject *KateMainWindow::pluginView(const QString &name)
     return m_pluginViews.contains(plugin) ? m_pluginViews.value(plugin) : 0;
 }
 
+void KateMainWindow::mousePressEvent(QMouseEvent *e)
+{
+    switch(e->button()) {
+        case Qt::ForwardButton:
+            slotFocusNextTab();
+            break;
+        case Qt::BackButton:
+            slotFocusPrevTab();
+            break;
+        default: ;
+    }
+}
+
 void KateMainWindow::slotFocusPrevTab()
 {
     if (m_viewManager->activeViewSpace()) {
