@@ -1015,6 +1015,9 @@ void KateViewManager::restoreViewConfiguration(const KConfigGroup &config)
         m_viewSpaceList.at(lastViewSpace)->currentView()->setFocus();
     }
 
+    // remove hidden view spaces (users will likely never find them again, #358266)
+    removeHiddenViewSpaces();
+
     // emergency
     if (m_viewSpaceList.empty()) {
         // kill bad children
@@ -1039,6 +1042,30 @@ void KateViewManager::restoreViewConfiguration(const KConfigGroup &config)
     updateViewSpaceActions();
 }
 
+void KateViewManager::removeHiddenViewSpaces()
+{
+    // collect all empty view spaces
+    QSet<KateViewSpace *> hiddenViewSpaces;
+    foreach (KateViewSpace *vs, m_viewSpaceList) {
+        if (vs->size().isEmpty()) {
+            hiddenViewSpaces.insert(vs);
+        }
+    }
+
+    // get all child splitters
+    const QList<QSplitter *> splitters = findChildren<QSplitter *>();
+    foreach (QSplitter * splitter, splitters) {
+        if (splitter->size().isEmpty()) {
+            hiddenViewSpaces += findChildren<KateViewSpace *>().toSet();
+        }
+    }
+
+    // finally remove all empty view spaces
+    foreach (KateViewSpace * vs, hiddenViewSpaces) {
+        removeViewSpace(vs);
+    }
+}
+
 void KateViewManager::saveSplitterConfig(QSplitter *s, KConfigBase *configBase, const QString &viewConfGrp)
 {
     QString grp = QString(viewConfGrp + QStringLiteral("-Splitter %1")).arg(m_splitterIndex);
